#' @name eval_preds
#' @title Evaluation of the predictions' quality
#' @description Given \code{observed} and \code{predicted} labels, evaluate the quality of the classification.
#' @param observed \emph{vector} \cr the observed classes in the test dataset.
#' @param predicted \emph{vector} \cr the predicted classes from the predict() method.
#' @return Returns \code{evaluation} object containing :
#' \itemize{
#' \item \code{cm} : the confusion matrix
#' \item \code{error} : the error score
#' }
#' @examples
#' eval_preds(observed = test_Y, predicted = predicted_label)
#' @export

eval_preds <- function(observed, predicted){
  #evaluation <- list()
  # Confusion matrix
  #n <- length(unique(observed))
  #cm <- as.matrix(table(observed,predicted),nrow =n,ncol=n)

  #Confusion matrix
  cm <- table(observed,predicted)
  cat(paste("\nConfusion matrix :\n\n"))
  print(cm)

  error = (1-sum(diag(cm)) / sum(cm))
  cat(paste("\nError =", error))
  cat("\n")

  #rappel
  recall <- diag(cm) / rowSums(cm)
  names(recall) <- levels(observed)
  cat("\nRecall =\n")
  print(recall)

  #precision
  precision <- diag(cm) / colSums(cm)
  names(precision) <- levels(observed)
  cat("\nPrecision =\n")
  print(precision)

  cat("\n")

  #evaluation$"confusion matrix" <- cm
  #evaluation$"error score" <- error
  #class(evaluation) <- "Predictions' evaluation"
  #return(evaluation)
}
