#' @name print
#' @title Printing Linear Discriminant Analysis object
#' @description Printing a LDA object in a convenient way
#' @param object \emph{LDA} \cr the object provided by the lda() procedure.
#' @param digits \emph{numeric} \cr the number of digits for printing values.
#' @param detailed \emp{boolean} \cr print additionnal information if TRUE.
#' @examples
#' print(object = adl, digits = 6)
#' @export


#printing the LDA object
print.LDA <- function(object,digits,detailed = FALSE){

  #information sur les donnees
  print(object$summary$"Dataset Information")
  cat('\n')

  #information sur les classes
  cat("Class Level Information :\n")
  print(object$summary$"Class Level Information")
  cat('\n')
  #recuperation des coefficients
  dfCoef <- data.frame(lapply(object$coefs,function(v){v}))

  #ajout de la constante
  dfCoef <- rbind(sapply(object$const,function(v){v}),dfCoef)
  rownames(dfCoef)[1] <- "_CONST_"

  #informations additionnelles
  if (detailed == TRUE){

    #logarithme du determinant
    print(object$"Pooled Covariance"$"Information")
    cat("\n")

    #matrice de covariance pooled
    cat("\nPooled Covariance Matrix:\n")
    print(object$"Pooled Covariance"$"Matrix")
    cat("\n")
  }


  #controler digits
  if (missing(digits)){digits <- NA} else {digits <- ifelse(is.numeric(digits)==TRUE,digits,NA)}

  #arrondi selon digits -- eventuellement
  if (is.na(digits) == FALSE){
    dfCoef <- round(dfCoef,digits)
  }

  #affichage des coefficients
  cat("\nClassification functions coefficients:\n")
  print(dfCoef)
  cat("\n")

}

