% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lda.R
\name{lda}
\alias{lda}
\title{Linear Discriminant Analysis.}
\source{
\url{http://www.math.wpi.edu/saspdf/stat/chap25.pdf}
\url{https://support.sas.com/documentation/cdl/en/statugdiscrim/61779/PDF/default/statugdiscrim.pdf}
\url{https://eric.univ-lyon2.fr/~ricco/cours/slides/analyse_discriminante.pdf}
}
\usage{
\strong{WITHOUT feature selection}
lda(data, target)

\strong{WITH stepwise feature selection} WITH intermediary outputs
lda(data, target, stepdisc=TRUE, method)

\strong{WITH stepwise feature selection} WITHOUT intermediary outputs
lda(data, target, stepdisc=TRUE, method, verbose=FALSE)
}
\arguments{
\item{data}{\emph{data.frame} \cr the training dataset containing explanatory and classification variables.}

\item{target}{\emph{character} \cr the classification variable name.}

\item{stepdisc}{\emph{boolean} \cr Does feature selection has to be performed ?\cr
FALSE \cr
TRUE (\emph{DEFAULT})}

\item{method}{\emph{character} \cr If stepdisc==TRUE, the feature selection method to be used :
\describe{
 \item{'forward'}{\emph{alternative :} 'F' | 'f' | 'forw'}
 \item{'backward'}{\emph{alternative :} 'B' | 'b' | 'back'}
 \item{'stepwise'}{\emph{alternative :} 'S' | 's' | 'step'}
}}

\item{verbose}{\emph{boolean} \cr TRUE : print intermediary steps during feature selection (\emph{DEFAULT})
\cr FALSE : print only feature selection' summary.}

\item{pval_cut}{\emph{numeric} \cr Specifies the significance level for adding or retaining variables in stepwise variable selection (\emph{DEFAULT = 0.05})}
}
\value{
Returns a \code{model} object containing :
\itemize{
 \item \code{features} (if stepdisc = TRUE)
 \item \code{levels}
 \item \code{const}
 \item \code{coefs}
 \item \code{Pooled Covariance} \emph{list}
   \itemize{
     \item Information \emph{data.frame}
     \item Matrix \emph{matrix}
   }
 \item \code{summary} \emph{list}
   \itemize{
     \item Dataset Information \emph{data.frame}\describe{
       \item{Total Sample Size}{}
       \item{Variables}{}
       \item{Classes}{}
       }
     \item Class Level Information \emph{data.frame}\describe{
       \item{frequency}{}
       \item{proportion}{}
       }
   }
}
}
\description{
For a given training dataset of observations containing :
\itemize{
 \item{\strong{explanatory variables} (\emph{quantitative or qualitative})}
 \item{and a \strong{classification variable} defining groups of observations}
 }
 The lda() function performs :
\enumerate{
  \item{ \strong{Feature selection} \emph{OPTIONAL}:\cr
  selects a subset of the quantitative variables to discriminate the classes\cr
  \emph{Inspired from SAS PROC STEPDISC (see ?stepdisc)}}

  \item{\strong{Linear Discriminant Analysis} :\cr
  develops a discriminant criterion to classify each observation into one of the groups.\cr
  \emph{Inspired from SAS PROC DISCRIM}}
 }
 The \code{model} obtained can be applied on a test dataset to predict the class of each observation. (\emph{see ?predict})\cr
}
\details{
\itemize{
  \item Categorical variables will be automatically converted into dummy variables.
}
}
\examples{

data(HRdata) # Load data

# WITHOUT feature selection
lda(data = HRdata, target = 'left')

# WITH feature selection - STEPWISE approach and WITH intermediary outputs
lda(data = HRdata, target = 'left', stepdisc = TRUE, method = 's')

# WITH feature selection - BACKWARD approach and WITHOUT intermediary outputs
lda(data = HRdata, target = 'left', stepdisc = TRUE, method = 'backward', verbose=FALSE)
}
