% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/stepdisc.R
\name{stepdisc}
\alias{stepdisc}
\title{Feature selection.}
\source{
\url{https://support.sas.com/documentation/cdl/en/statug/63347/HTML/default/viewer.htm#stepdisc_toc.htm}
\url{https://support.sas.com/documentation/cdl/en/statugstepdisc/61834/PDF/default/statugstepdisc.pdf}
\url{https://eric.univ-lyon2.fr/~ricco/cours/slides/filtrage_predicteurs.pdf}
}
\usage{
stepdisc(var, class_vec, method, pval_cut = 0.05, verbose = TRUE)
}
\arguments{
\item{var}{\emph{data.frame}}

\item{class_vec}{\emph{character}}

\item{method}{\emph{character}
\describe{
 \item{'forward'}{\emph{alternative :} 'F' | 'f' | 'forw'}
 \item{'backward'}{\emph{alternative :} 'B' | 'b' | 'back'}
 \item{'stepwise'}{\emph{alternative :} 'S' | 's' | 'step'}
}}

\item{pval_cut}{\emph{character}}

\item{verbose}{\emph{boolean} \cr TRUE : print intermediary steps during feature selection (\emph{DEFAULT})
\cr FALSE : print only feature selection' summary.}
}
\value{
Returns the list of \code{features} selected.
}
\description{
Given a classification variable and several quantitative variables, the stepdisc function
selects a subset of the quantitative variables to discriminate the classes.\cr\cr
3 approaches are available :
\describe{
 \item{\strong{Forward selection}}{
   \enumerate{
     \item Begins with \strong{no variables} in the model.
     \item At each step, the variable that contributes most to the discriminatory power of the model (measured by Wilks’
lambda) is entered.
     \item When none of the unselected variables meet the entry criterion, the forward selection process stops.
    }}
 \item{\strong{Backward elimination}}{
   \enumerate{
     \item Begins with \strong{all variables} in the model.
     \item At each step, the variable that contributes least to the
     discriminatory power of the model (measured by Wilks’ lambda)  is removed.
     \item When all remaining variables meet the criterion to stay in the model, the backward elimination process stops
    }}
 \item{\strong{Stepwise selection}}{
   \enumerate{
     \item Begins with \strong{no variables} in the model
     \item At each step, the model is examined.
       \itemize{
         \item If the variable in the model that contributes least to the discriminatory power of the model (measured by Wilks’ lambda) fails to meet the criterion to stay, then that variable is removed.
         \item Otherwise, the variable not in the model that contributes most to the discriminatory power of the model is entered.
       }
     \item When all variables in the model meet the criterion to stay and none of the
     other variables meet the criterion to enter, the stepwise selection process stops.
    }}}\cr
 \emph{Inspired from SAS PROC STEPDISC}
}
\examples{

data(HRdata) # Load data
target ='left' # define target

# Split data
train_X <- HRdata[,colnames(data) != target]
train_Y <- HRdata[, target]

# Feature selection using stepwise approach
stepdisc(var = train_X, class_vec = train_Y, method = 'stepwise', pval_cut=0.05)

#' # Feature selection using forward approach
stepdisc(var = train_X, class_vec = train_Y, method = 'f', pval_cut=0.05)
}
